==> zio-aws-ec2_2.12-6.20.78.1-sources.jar: zio/aws/ec2/model/ModifyIpamResourceDiscoveryRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.IpamResourceDiscoveryId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ModifyIpamResourceDiscoveryRequest(
    ipamResourceDiscoveryId: IpamResourceDiscoveryId,
    description: Optional[String] = Optional.Absent,
    addOperatingRegions: Optional[
      Iterable[zio.aws.ec2.model.AddIpamOperatingRegion]
    ] = Optional.Absent,
    removeOperatingRegions: Optional[
      Iterable[zio.aws.ec2.model.RemoveIpamOperatingRegion]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyIpamResourceDiscoveryRequest = {
    import ModifyIpamResourceDiscoveryRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyIpamResourceDiscoveryRequest
      .builder()
      .ipamResourceDiscoveryId(
        IpamResourceDiscoveryId.unwrap(
          ipamResourceDiscoveryId
        ): java.lang.String
      )
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(
        addOperatingRegions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.addOperatingRegions)
      .optionallyWith(
        removeOperatingRegions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.removeOperatingRegions)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.ModifyIpamResourceDiscoveryRequest.ReadOnly =
    zio.aws.ec2.model.ModifyIpamResourceDiscoveryRequest.wrap(buildAwsValue())
}
object ModifyIpamResourceDiscoveryRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyIpamResourceDiscoveryRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyIpamResourceDiscoveryRequest =
      zio.aws.ec2.model.ModifyIpamResourceDiscoveryRequest(
        ipamResourceDiscoveryId,
        description.map(value => value),
        addOperatingRegions.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        removeOperatingRegions.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def ipamResourceDiscoveryId: IpamResourceDiscoveryId
    def description: Optional[String]
    def addOperatingRegions
        : Optional[List[zio.aws.ec2.model.AddIpamOperatingRegion.ReadOnly]]
    def removeOperatingRegions
        : Optional[List[zio.aws.ec2.model.RemoveIpamOperatingRegion.ReadOnly]]
    def getIpamResourceDiscoveryId: ZIO[Any, Nothing, IpamResourceDiscoveryId] =
      ZIO.succeed(ipamResourceDiscoveryId)
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getAddOperatingRegions: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.AddIpamOperatingRegion.ReadOnly
    ]] = AwsError.unwrapOptionField("addOperatingRegions", addOperatingRegions)
    def getRemoveOperatingRegions: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.RemoveIpamOperatingRegion.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "removeOperatingRegions",
      removeOperatingRegions
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyIpamResourceDiscoveryRequest
  ) extends zio.aws.ec2.model.ModifyIpamResourceDiscoveryRequest.ReadOnly {
    override val ipamResourceDiscoveryId: IpamResourceDiscoveryId =
      zio.aws.ec2.model.primitives
        .IpamResourceDiscoveryId(impl.ipamResourceDiscoveryId())
    override val description: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => value: String)
    override val addOperatingRegions
        : Optional[List[zio.aws.ec2.model.AddIpamOperatingRegion.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.addOperatingRegions())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.AddIpamOperatingRegion.wrap(item)
          }.toList
        )
    override val removeOperatingRegions
        : Optional[List[zio.aws.ec2.model.RemoveIpamOperatingRegion.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.removeOperatingRegions())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.RemoveIpamOperatingRegion.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyIpamResourceDiscoveryRequest
  ): zio.aws.ec2.model.ModifyIpamResourceDiscoveryRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.12-7.21.15.11-sources.jar: zio/aws/ec2/model/ModifyIpamResourceDiscoveryRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.IpamResourceDiscoveryId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ModifyIpamResourceDiscoveryRequest(
    dryRun: Optional[Boolean] = Optional.Absent,
    ipamResourceDiscoveryId: IpamResourceDiscoveryId,
    description: Optional[String] = Optional.Absent,
    addOperatingRegions: Optional[
      Iterable[zio.aws.ec2.model.AddIpamOperatingRegion]
    ] = Optional.Absent,
    removeOperatingRegions: Optional[
      Iterable[zio.aws.ec2.model.RemoveIpamOperatingRegion]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyIpamResourceDiscoveryRequest = {
    import ModifyIpamResourceDiscoveryRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyIpamResourceDiscoveryRequest
      .builder()
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .ipamResourceDiscoveryId(
        IpamResourceDiscoveryId.unwrap(
          ipamResourceDiscoveryId
        ): java.lang.String
      )
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(
        addOperatingRegions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.addOperatingRegions)
      .optionallyWith(
        removeOperatingRegions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.removeOperatingRegions)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.ModifyIpamResourceDiscoveryRequest.ReadOnly =
    zio.aws.ec2.model.ModifyIpamResourceDiscoveryRequest.wrap(buildAwsValue())
}
object ModifyIpamResourceDiscoveryRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyIpamResourceDiscoveryRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyIpamResourceDiscoveryRequest =
      zio.aws.ec2.model.ModifyIpamResourceDiscoveryRequest(
        dryRun.map(value => value),
        ipamResourceDiscoveryId,
        description.map(value => value),
        addOperatingRegions.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        removeOperatingRegions.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def dryRun: Optional[Boolean]
    def ipamResourceDiscoveryId: IpamResourceDiscoveryId
    def description: Optional[String]
    def addOperatingRegions
        : Optional[List[zio.aws.ec2.model.AddIpamOperatingRegion.ReadOnly]]
    def removeOperatingRegions
        : Optional[List[zio.aws.ec2.model.RemoveIpamOperatingRegion.ReadOnly]]
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
    def getIpamResourceDiscoveryId: ZIO[Any, Nothing, IpamResourceDiscoveryId] =
      ZIO.succeed(ipamResourceDiscoveryId)
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getAddOperatingRegions: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.AddIpamOperatingRegion.ReadOnly
    ]] = AwsError.unwrapOptionField("addOperatingRegions", addOperatingRegions)
    def getRemoveOperatingRegions: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.RemoveIpamOperatingRegion.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "removeOperatingRegions",
      removeOperatingRegions
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyIpamResourceDiscoveryRequest
  ) extends zio.aws.ec2.model.ModifyIpamResourceDiscoveryRequest.ReadOnly {
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
    override val ipamResourceDiscoveryId: IpamResourceDiscoveryId =
      zio.aws.ec2.model.primitives
        .IpamResourceDiscoveryId(impl.ipamResourceDiscoveryId())
    override val description: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => value: String)
    override val addOperatingRegions
        : Optional[List[zio.aws.ec2.model.AddIpamOperatingRegion.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.addOperatingRegions())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.AddIpamOperatingRegion.wrap(item)
          }.toList
        )
    override val removeOperatingRegions
        : Optional[List[zio.aws.ec2.model.RemoveIpamOperatingRegion.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.removeOperatingRegions())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.RemoveIpamOperatingRegion.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyIpamResourceDiscoveryRequest
  ): zio.aws.ec2.model.ModifyIpamResourceDiscoveryRequest.ReadOnly =
    new Wrapper(impl)
}
